@@ -6,7 +6,8 @@ import time
 import hashlib
 from contextlib import contextmanager
 
-from browserid.utils import encode_bytes, bundle_certs_and_assertion
+from browserid.utils import (encode_bytes, bundle_certs_and_assertion,
+                             to_int, to_hex)
 
 from browserid import supportdoc
 from browserid import jwt
@@ -25,29 +26,22 @@ except ImportError:
 #    SHA-256 under the category A.2.3 Verifiable Canonical Generation of the
 #    Generator g
 #    """
-DUMMY_Q = long("e21e04f911d1ed7991008ecaab3bf775984309c3", 16)
+DUMMY_Q = to_int("e21e04f911d1ed7991008ecaab3bf775984309c3", 16)
 
-DUMMY_P = long("""
+
+DUMMY_P = to_int("""
   ff600483db6abfc5b45eab78594b3533d550d9f1bf2a992a7a8daa6dc34f8045ad4e6e0c429
   d334eeeaaefd7e23d4810be00e4cc1492cba325ba81ff2d5a5b305a8d17eb3bf4a06a349d39
   2e00d329744a5179380344e82a18c47933438f891e22aeef812d69c8f75e326cb70ea000c3f
   776dfdbd604638c2ef717fc26d02e17
-""".replace(" ", "").replace("\n", "").strip(), 16)
+""", 16)
 
-DUMMY_G = long("""
+DUMMY_G = to_int("""
   c52a4a0ff3b7e61fdf1867ce84138369a6154f4afa92966e3c827e25cfa6cf508b90e5de419
   e1337e07a2e9e2a3cd5dea704d175f8ebf6af397d69e110b96afb17c7a03259329e4829b0d0
   3bbc7896b15b4ade53e130858cc34d96269aa89041f409136c7242a38895c9d5bccad4f389a
   f1d7a4bd1398bd072dffa896233397a
-""".replace(" ", "").replace("\n", "").strip(), 16)
-
-
-def _hex(value):
-    """Like the builtin hex(), but without formatting guff."""
-    value = hex(value)[2:]
-    if value.endswith("L"):
-        value = value[:-1]
-    return value
+""", 16)
 
 
 def fetch_support_document(hostname, verify=None):
@@ -88,17 +82,17 @@ def get_keypair(hostname):
     p = DUMMY_P
     g = DUMMY_G
     # Generate private key x by "some random method".
-    x = long(hashlib.sha1(hostname).hexdigest(), 16)
+    x = to_int(hashlib.sha1(hostname.encode("utf8")).hexdigest(), 16)
     assert x != 0, "SHA1(hostname) is zero - what are the odds?!"
     # Calculate public key y as usual.
     y = pow(g, x, p)
     data = {
       "algorithm": "DS",
-      "p": _hex(p),
-      "q": _hex(q),
-      "g": _hex(g),
-      "y": _hex(y),
-      "x": _hex(x),
+      "p": to_hex(p),
+      "q": to_hex(q),
+      "g": to_hex(g),
+      "y": to_hex(y),
+      "x": to_hex(x),
     }
     privkey = jwt.DS128Key(data)
     del data["x"]
